import React from 'react';
import ReactDOM from 'react-dom';
import { Modal, List, Menu, Button, Input, Label, Table } from 'semantic-ui-react';
import Datetime from 'react-datetime';
import {convertTime, padding} from '../../../../tools'

const getDayTime = ()=>{
    let d = new Date();
    d.setHours(0, 0, 0, 0);
    return d.getTime();
}

class WristbandPathInfo extends React.Component{
    state = {
        list: [],
        stime: (getDayTime()),
        etime: (Date.now())
    }

    componentDidMount(){

    }

    closeView = () => {
        this.setState({
            list: [],
            stime: (getDayTime()),
            etime: (Date.now())
        }, ()=>{
            this.props.closeModal();
        })
    }

    getList = () => {
        let {mac, showDialog, getRequest} = this.props;
        fetch('/api/wristband/getwristbandhealthinfo', getRequest({
            mac,
            stime: Math.floor(this.state.stime / 1000),
            etime: Math.floor(this.state.etime / 1000)
            }))
            .then(response=>response.json())
            .then(json => {
                if(json.status != 1) return showDialog(json.message);
                this.setState({
                    list: json.data.record || []
                })
            })
    }

    render() {
        let {closeModal, open} = this.props;
        return (
            <Modal open={open} onClose={()=>{this.closeView()}}>
                <Modal.Header>
                    手環名稱: {this.props.wbname}
                </Modal.Header>
                <Modal.Content>
                    <Menu>
                        <Menu.Item>
                            <Input label="起始時間" input={
                            <Datetime dateFormat="YYYY-MM-DD" 
                                timeFormat="HH:mm" 
                                value={this.state.stime} 
                                input={true}
                                onChange={(e)=>{ this.setState({stime: (e.valueOf())}) }} />
                            }/>
                        </Menu.Item>
                        <Menu.Item>
                            <Input label="結束時間" input={
                            <Datetime dateFormat="YYYY-MM-DD" 
                                timeFormat="HH:mm" 
                                value={this.state.etime} 
                                input={true}
                                onChange={(e)=>{ this.setState({etime: (e.valueOf())}) }} />
                            }/>
                        </Menu.Item>
                        <Menu.Menu position="right">
                            <Menu.Item>
                                <Button type="button" content="搜尋" size="tiny" basic onClick={()=>{this.getList()}} />
                            </Menu.Item>
                        </Menu.Menu>
                    </Menu>
                    <Table>
                        <Table.Header>
                            <Table.Row>
                                <Table.HeaderCell>HR</Table.HeaderCell>
                                <Table.HeaderCell>步數</Table.HeaderCell>
                                <Table.HeaderCell>SBP</Table.HeaderCell>
                                <Table.HeaderCell>DBP</Table.HeaderCell>
                                <Table.HeaderCell>卡路里</Table.HeaderCell>
                                <Table.HeaderCell>SOS</Table.HeaderCell>
                                <Table.HeaderCell>更新時間</Table.HeaderCell>
                            </Table.Row>
                        </Table.Header>
                        <Table.Body>
                            {
                                this.state.list.map((t,idx) => {
                                    return (
                                        <Table.Row key={idx}>
                                            <Table.Cell>{parseInt(t.wphyloghr, 16)}</Table.Cell>
                                            <Table.Cell>{parseInt(t.wphylogsteps, 16)}</Table.Cell>
                                            <Table.Cell>{parseInt(t.wphylogsbp, 16)}</Table.Cell>
                                            <Table.Cell>{parseInt(t.wphylogdbp, 16)}</Table.Cell>
                                            <Table.Cell>{parseInt(t.wphylogcal, 16)}</Table.Cell>
                                            <Table.Cell>{parseInt(t.wphylogsos, 16)}</Table.Cell>
                                            <Table.Cell>{convertTime(t.wphylogtst, true)}</Table.Cell>
                                        </Table.Row>
                                    )
                                })
                            }
                        </Table.Body>
                    </Table>
                </Modal.Content>
            </Modal>
        )
    }
}

export default WristbandPathInfo;